Trait style::selector_map::SelectorMapEntry
[−]
[src]
pub trait SelectorMapEntry: Sized + Clone {
fn selector(&self) -> SelectorIter<SelectorImpl>;
}A trait to abstract over a given selector map entry.
Required Methods
ⓘImportant traits for SelectorIter<'a, Impl>
fn selector(&self) -> SelectorIter<SelectorImpl>
Gets the selector we should use to index in the selector map.
Implementors
impl SelectorMapEntry for Dependencyimpl SelectorMapEntry for StateDependencyimpl SelectorMapEntry for Rule